MapRecord

Struct MapRecord 

#[repr(C)]
pub struct MapRecord<K, V> { pub key: K, pub value: V, pub hash: u64, }
One gathered map entry.

Scatter sites store the hash next to the key and value so map initialization only needs to place rows into metadata slots.

Fields

key: K

The key of the record.

value: V

The value of the record.

hash: u64

The hash of the record.

Implementations

Source

impl<K, V> MapRecord<K, V>

pub const fn new(key: K, value: V, hash: u64) -> Self

Create a new map record with a key, value and known const hash.