#[repr(C)]pub struct MapRecord<K, V> {
pub key: K,
pub value: V,
pub hash: u64,
}Expand description
One gathered map entry.
Scatter sites store the hash next to the key and value so map initialization only needs to place rows into metadata slots.
Fields
key: KThe key of the record.
value: VThe value of the record.
hash: u64The hash of the record.
Implementations